import { Shield, Heart, Home as HomeIcon, Receipt, Gift, Calculator } from "lucide-react";
import { CalculatorCard } from "@/components/calculator-card";
import { VisitorCounter } from "@/components/visitor-counter";
import { Button } from "@/components/ui/button";
import { Link } from "wouter";
import { useQuery, useMutation, useQueryClient } from "@tanstack/react-query";
import { useEffect } from "react";
import { apiRequest } from "@/lib/queryClient";

export default function Home() {
  const queryClient = useQueryClient();

  // Track visitor on page load
  const trackVisitor = useMutation({
    mutationFn: async () => {
      return apiRequest("POST", "/api/visitors", {});
    },
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey: ["/api/visitors/stats"] });
    },
  });

  useEffect(() => {
    trackVisitor.mutate();
  }, []);

  const calculators = [
    {
      title: "All-in-One Calculator",
      description: "Calculate all your government contributions and taxes in one comprehensive tool - SSS, Philhealth, PAG-IBIG, Income Tax, and 13th Month Pay.",
      icon: Calculator,
      href: "/all-in-one-calculator",
      stats: [
        { label: "Calculators", value: "5-in-1" },
        { label: "Updated", value: "2025" },
        { label: "Comprehensive", value: "Yes" },
      ],
      buttonText: "Calculate All",
      iconBgColor: "bg-filipino-green",
      buttonColor: "bg-filipino-green hover:bg-green-700",
    },
    {
      title: "SSS Contributions",
      description: "Calculate your Social Security System contributions based on your monthly salary compensation.",
      icon: Shield,
      href: "/sss-calculator",
      stats: [
        { label: "Employee Rate", value: "4.5%" },
        { label: "Employer Rate", value: "9.5%" },
        { label: "Max Salary", value: "₱30,000" },
      ],
      buttonText: "Calculate SSS",
      iconBgColor: "bg-filipino-blue",
      buttonColor: "bg-filipino-blue hover:bg-blue-700",
    },
    {
      title: "Philhealth Contributions",
      description: "Calculate your Philippine Health Insurance Corporation premium contributions.",
      icon: Heart,
      href: "/philhealth-calculator",
      stats: [
        { label: "Premium Rate", value: "5.0%" },
        { label: "Employee Share", value: "2.5%" },
        { label: "Max Salary", value: "₱100,000" },
      ],
      buttonText: "Calculate Philhealth",
      iconBgColor: "bg-filipino-green",
      buttonColor: "bg-filipino-green hover:bg-green-700",
    },
    {
      title: "PAG-IBIG Contributions",
      description: "Calculate your Home Development Mutual Fund contributions for housing benefits.",
      icon: HomeIcon,
      href: "/pagibig-calculator",
      stats: [
        { label: "Employee Rate", value: "1-2%" },
        { label: "Employer Rate", value: "2%" },
        { label: "Max Salary", value: "₱5,000" },
      ],
      buttonText: "Calculate PAG-IBIG",
      iconBgColor: "bg-filipino-yellow",
      buttonColor: "bg-filipino-yellow hover:bg-yellow-400 text-gray-900",
    },
    {
      title: "Income Withholding Tax",
      description: "Calculate your Bureau of Internal Revenue income tax withholding based on TRAIN law.",
      icon: Receipt,
      href: "/income-tax-calculator",
      stats: [
        { label: "Tax Exempt", value: "Up to ₱250,000" },
        { label: "Max Rate", value: "35%" },
        { label: "Updated", value: "2025 BIR" },
      ],
      buttonText: "Calculate Tax",
      iconBgColor: "bg-filipino-red",
      buttonColor: "bg-filipino-red hover:bg-red-700",
    },
    {
      title: "13th Month Pay",
      description: "Calculate your 13th month pay and its corresponding tax obligations.",
      icon: Gift,
      href: "/thirteenth-month-calculator",
      stats: [
        { label: "Tax Exempt", value: "Up to ₱90,000" },
        { label: "Computation", value: "Annual Basic / 12" },
        { label: "Required", value: "All employees" },
      ],
      buttonText: "Calculate 13th Month",
      iconBgColor: "bg-purple-600",
      buttonColor: "bg-purple-600 hover:bg-purple-700",
    },
  ];

  return (
    <div className="min-h-screen bg-gray-50 dark:bg-dark-bg">
      <VisitorCounter />
      
      {/* Optimized Hero Section for LCP */}
      <section className="hero-gradient text-white py-16" style={{
        background: 'linear-gradient(to right, hsl(207, 90%, 54%), hsl(0, 84.2%, 60.2%))',
        willChange: 'auto'
      }}>
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center">
            <h1 className="hero-text" style={{
              fontSize: 'clamp(2.25rem, 5vw, 3.75rem)',
              fontWeight: 700,
              lineHeight: 1.2,
              marginBottom: '1.5rem',
              color: 'inherit'
            }}>
              Filipino Employee Benefits Calculator
            </h1>
            <p className="text-xl md:text-2xl mb-8 max-w-3xl mx-auto">
              Calculate your monthly SSS, Philhealth, PAG-IBIG contributions and income tax withholding. 
              Updated for 2025 rates and regulations.
            </p>
            <div className="flex justify-center space-x-4 flex-wrap gap-4">
              <Link href="/all-in-one-calculator">
                <Button size="lg" className="bg-filipino-yellow text-gray-900 hover:bg-yellow-400">
                  <Calculator className="h-5 w-5 mr-2" />
                  All-in-One Calculator
                </Button>
              </Link>
              <Link href="/2025-updates">
                <Button size="lg" variant="outline" className="border-white text-white hover:bg-white hover:text-filipino-blue">
                  Learn About 2025 Updates
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Calculator Grid */}
      <section className="py-16 bg-white dark:bg-dark-bg">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold text-gray-900 dark:text-white mb-4">
              Choose Your Calculator
            </h2>
            <p className="text-lg text-gray-600 dark:text-gray-300 max-w-2xl mx-auto">
              Select the calculator you need to compute your monthly deductions and contributions
            </p>
          </div>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {calculators.map((calculator, index) => (
              <CalculatorCard key={index} {...calculator} />
            ))}
            

          </div>
        </div>
      </section>
    </div>
  );
}
